@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2015-07-12'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2015-07-20'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use strict;
@@ -138,13 +138,13 @@ sub munge_files {
         my $ver = 0;
         my %mem;
         my $perimod = $res->[3]{'func.cmdline_module'};
-        unless ($res->[3]{'func.cmdline_module_inlined'}) {
-            $self->log_debug(["Adding prereq to %s", $perimod]);
-            $self->zilla->register_prereqs(
-                {phase => 'runtime'}, $perimod =>
-                    $res->[3]{'func.cmdline_module_version'});
-            $mem{$perimod}++;
-        }
+        $self->log_debug(["Adding prereq to %s", $perimod]);
+        $self->zilla->register_prereqs(
+            {phase => $res->[3]{'func.cmdline_module_inlined'} ?
+                 'build' : 'runtime'},
+            $perimod => $res->[3]{'func.cmdline_module_version'});
+        $mem{$perimod}++;
+
         my @urls = ($self->url);
         if ($subcommands && @$subcommands) {
             for my $sc (@$subcommands) {
@@ -187,7 +187,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.20 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-07-12.
+This document describes version 0.21 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-07-20.
 
 =head1 SYNOPSIS
 
